/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.blob.suite;

import static com.google.common.truth.Truth.assertThat;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.Random;

import org.apache.axiom.blob.WritableBlob;
import org.apache.axiom.blob.WritableBlobFactory;
import org.apache.commons.io.IOUtils;

public class TestResetWithoutMark extends WritableBlobTestCase {
    public TestResetWithoutMark(WritableBlobFactory<?> factory) {
        super(factory, State.NEW);
    }

    @Override
    protected void runTest(WritableBlob blob) throws Throwable {
        Random random = new Random();
        byte[] sourceData = new byte[1024];
        random.nextBytes(sourceData);
        OutputStream out = blob.getOutputStream();
        out.write(sourceData);
        out.close();
        InputStream in = blob.getInputStream();
        try {
            byte[] data1 = new byte[sourceData.length];
            byte[] data2 = new byte[sourceData.length];
            IOUtils.readFully(in, data1);
            in.reset();
            IOUtils.readFully(in, data2);
            assertThat(data1).isEqualTo(sourceData);
            assertThat(data2).isEqualTo(sourceData);
        } finally {
            in.close();
        }
    }
}
